aboutsummaryrefslogtreecommitdiffstats
path: root/packages
diff options
context:
space:
mode:
authorGreg Hysen <greg.hysen@gmail.com>2018-04-14 05:49:53 +0800
committerAmir Bandeali <abandeali1@gmail.com>2018-04-21 04:56:18 +0800
commit1cace49b744f216f0558880a80675463737f6a12 (patch)
tree2aa6877b638fdbb804577811ee38db22c715fa79 /packages
parent7ab54421630a95d5b646982d1bcc4a9d318f5c6c (diff)
downloaddexon-sol-tools-1cace49b744f216f0558880a80675463737f6a12.tar
dexon-sol-tools-1cace49b744f216f0558880a80675463737f6a12.tar.gz
dexon-sol-tools-1cace49b744f216f0558880a80675463737f6a12.tar.bz2
dexon-sol-tools-1cace49b744f216f0558880a80675463737f6a12.tar.lz
dexon-sol-tools-1cace49b744f216f0558880a80675463737f6a12.tar.xz
dexon-sol-tools-1cace49b744f216f0558880a80675463737f6a12.tar.zst
dexon-sol-tools-1cace49b744f216f0558880a80675463737f6a12.zip
address -> IAssetProxy where possible for clarity
Diffstat (limited to 'packages')
-rw-r--r--packages/contracts/src/contracts/current/protocol/AssetProxyDispatcher/AssetProxyDispatcher.sol14
-rw-r--r--packages/contracts/src/contracts/current/protocol/AssetProxyDispatcher/IAssetProxyDispatcher.sol12
2 files changed, 13 insertions, 13 deletions
diff --git a/packages/contracts/src/contracts/current/protocol/AssetProxyDispatcher/AssetProxyDispatcher.sol b/packages/contracts/src/contracts/current/protocol/AssetProxyDispatcher/AssetProxyDispatcher.sol
index f2c942870..69e4e186d 100644
--- a/packages/contracts/src/contracts/current/protocol/AssetProxyDispatcher/AssetProxyDispatcher.sol
+++ b/packages/contracts/src/contracts/current/protocol/AssetProxyDispatcher/AssetProxyDispatcher.sol
@@ -55,21 +55,21 @@ contract AssetProxyDispatcher is
/// @dev Adds a new asset proxy.
/// @param assetProxyId Id of the asset proxy.
/// @param newAssetProxyAddress Address of the asset proxy contract to add.
/// @param currentAssetProxyAddress Address of existing asset proxy to overwrite.
function addAssetProxy(
uint8 assetProxyId,
- address newAssetProxyAddress,
- address currentAssetProxyAddress)
+ IAssetProxy newAssetProxy,
+ IAssetProxy currentAssetProxy)
external
onlyOwner
{
// Ensure the existing asset proxy is not unintentionally overwritten
- require(currentAssetProxyAddress == address(assetProxies[assetProxyId]));
+ require(currentAssetProxy == assetProxies[assetProxyId]);
// Add asset proxy and log registration
- assetProxies[assetProxyId] = IAssetProxy(newAssetProxyAddress);
- emit AssetProxySet(assetProxyId, newAssetProxyAddress, currentAssetProxyAddress);
+ assetProxies[assetProxyId] = newAssetProxy;
+ emit AssetProxySet(assetProxyId, newAssetProxy, currentAssetProxy);
}
/// @dev Gets an asset proxy.
@@ -55,21 +55,21 @@ contract AssetProxyDispatcher is
/// @dev Adds a new asset proxy.
/// @param assetProxyId Id of the asset proxy.
- /// @param newAssetProxyAddress Address of the asset proxy contract to add.
- /// @param currentAssetProxyAddress Address of existing asset proxy to overwrite.
+ /// @param newAssetProxy Asset proxy contract to add.
+ /// @param currentAssetProxy Existing asset proxy to overwrite.
function addAssetProxy(
uint8 assetProxyId,
diff --git a/packages/contracts/src/contracts/current/protocol/AssetProxyDispatcher/IAssetProxyDispatcher.sol b/packages/contracts/src/contracts/current/protocol/AssetProxyDispatcher/IAssetProxyDispatcher.sol
index b8ea0a49f..75aead745 100644
--- a/packages/contracts/src/contracts/current/protocol/AssetProxyDispatcher/IAssetProxyDispatcher.sol
+++ b/packages/contracts/src/contracts/current/protocol/AssetProxyDispatcher/IAssetProxyDispatcher.sol
@@ -25,18 +25,18 @@ contract IAssetProxyDispatcher {
// Logs registration of new asset proxy
event AssetProxySet(
uint8 id,
- address newAssetClassAddress,
- address oldAssetClassAddress
+ IAssetProxy newAssetClassAddress,
+ IAssetProxy oldAssetClassAddress
);
/// @dev Adds a new asset proxy.
/// @param assetProxyId Id of the asset proxy.
/// @param newAssetProxyAddress Address of the asset proxy contract to add.
/// @param currentAssetProxyAddress Address of existing asset proxy to overwrite.
function addAssetProxy(
uint8 assetProxyId,
- address newAssetProxyAddress,
- address currentAssetProxyAddress)
+ IAssetProxy newAssetProxy,
+ IAssetProxy currentAssetProxy)
external;
/// @dev Gets an asset proxy.
@@ -25,18 +25,18 @@ contract IAssetProxyDispatcher {
/// @dev Adds a new asset proxy.
/// @param assetProxyId Id of the asset proxy.
- /// @param newAssetProxyAddress Address of the asset proxy contract to add.
- /// @param currentAssetProxyAddress Address of existing asset proxy to overwrite.
+ /// @param newAssetProxy Asset proxy contract to add.
+ /// @param currentAssetProxy Existing asset proxy to overwrite.
function addAssetProxy(
uint8 assetProxyId,